import * as nubes from "nubes-collections";
/**
 * The Key of INI
 *
 * @export
 * @class Key
 * @extends {(nubes.KeyValue<string, string | number>)}
 */
export declare class Key extends nubes.KeyValue<string, string | number> {
    /**
     * Creates an instance of Key.
     *
     * @param {string} key
     * @param {(string | number)} value
     */
    constructor(key: string, value: string | number);
}
/**
 * The list of Keys
 *
 * @export
 * @class KeyList
 * @extends {nubes.List<Key>}
 */
export declare class KeyList extends nubes.List<Key> {
    /**
     * Use the Key's name to get the key.
     *
     * @param {string} key The key of the key-value
     * @returns {Key}
     */
    getByName(key: string): Key;
}
/**
 * The Section of the INI
 *
 * @export
 * @class Section
 */
export declare class Section {
    /**
     * The name of the Section
     *
     * @private
     * @type {string}
     */
    name: string;
    /**
     * The Section's list of keys.
     *
     * @type {KeyList}
     */
    keys: KeyList;
    /**
     * Creates an instance of Section.
     *
     * @param {string} name The section's name
     */
    constructor(name: string);
}
/**
 * The list of sections
 *
 * @export
 * @class SectionList
 * @extends {nubes.List<Section>}
 */
export declare class SectionList extends nubes.List<Section> {
    /**
     * Use the name to get the section
     *
     * @param {string} name The name of section
     * @returns {Section}
     */
    getByName(name: string): Section;
}
/**
 * The INI class
 *
 * @export
 * @class INI
 */
export declare class INI {
    /**
     * The section checking regex
     *
     * @private
     * @static
     */
    private static _sectionRegex;
    /**
     * The section list of INI
     *
     * @type {SectionList}
     */
    sections: SectionList;
    /**
     * Convert string content to INI object
     *
     * @static
     * @param {string} content
     * @returns {INI}
     */
    static convertToINI(content: string): INI;
    /**
     * Convert INI object to string
     *
     * @static
     * @param {INI} ini
     * @returns {string}
     */
    static convertToString(ini: INI): string;
}
