"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var nubes = require("nubes-collections");
/**
 * The Key of INI
 *
 * @export
 * @class Key
 * @extends {(nubes.KeyValue<string, string | number>)}
 */
var Key = (function (_super) {
    __extends(Key, _super);
    /**
     * Creates an instance of Key.
     *
     * @param {string} key
     * @param {(string | number)} value
     */
    function Key(key, value) {
        _super.call(this, key, value);
    }
    return Key;
}(nubes.KeyValue));
exports.Key = Key;
/**
 * The list of Keys
 *
 * @export
 * @class KeyList
 * @extends {nubes.List<Key>}
 */
var KeyList = (function (_super) {
    __extends(KeyList, _super);
    function KeyList() {
        _super.apply(this, arguments);
    }
    /**
     * Use the Key's name to get the key.
     *
     * @param {string} key The key of the key-value
     * @returns {Key}
     */
    KeyList.prototype.getByName = function (key) {
        for (var index = 0; index < this.count; index++) {
            var element = this.get(index);
            if (element.key == key) {
                return element;
            }
        }
    };
    return KeyList;
}(nubes.List));
exports.KeyList = KeyList;
/**
 * The Section of the INI
 *
 * @export
 * @class Section
 */
var Section = (function () {
    /**
     * Creates an instance of Section.
     *
     * @param {string} name The section's name
     */
    function Section(name) {
        /**
         * The Section's list of keys.
         *
         * @type {KeyList}
         */
        this.keys = new KeyList();
        this.name = name;
    }
    return Section;
}());
exports.Section = Section;
/**
 * The list of sections
 *
 * @export
 * @class SectionList
 * @extends {nubes.List<Section>}
 */
var SectionList = (function (_super) {
    __extends(SectionList, _super);
    function SectionList() {
        _super.apply(this, arguments);
    }
    /**
     * Use the name to get the section
     *
     * @param {string} name The name of section
     * @returns {Section}
     */
    SectionList.prototype.getByName = function (name) {
        for (var index = 0; index < this.count; index++) {
            var element = this.get(index);
            if (element.name == name) {
                return element;
            }
        }
    };
    return SectionList;
}(nubes.List));
exports.SectionList = SectionList;
/**
 * The INI class
 *
 * @export
 * @class INI
 */
var INI = (function () {
    function INI() {
        /**
         * The section list of INI
         *
         * @type {SectionList}
         */
        this.sections = new SectionList();
    }
    /**
     * Convert string content to INI object
     *
     * @static
     * @param {string} content
     * @returns {INI}
     */
    INI.convertToINI = function (content) {
        var result = new INI();
        var currentSectionCounter = -1;
        var stringList = content.split('\n');
        for (var _i = 0, stringList_1 = stringList; _i < stringList_1.length; _i++) {
            var statement = stringList_1[_i];
            // Section check
            if (this._sectionRegex.test(statement) == true) {
                var regexResult = this._sectionRegex.exec(statement);
                result.sections.add(new Section(regexResult[1]));
                currentSectionCounter += 1;
            }
            else if (statement[0] == '#' || statement[0] == ';' || statement[0] == '\n' || statement[0] == '\r\n' || statement[0] == '\r') {
                continue;
            }
            else {
                var key = "";
                var value = "";
                var swticher = false;
                for (var _a = 0, statement_1 = statement; _a < statement_1.length; _a++) {
                    var char = statement_1[_a];
                    if (char == '=' && swticher == false) {
                        swticher = true;
                        continue;
                    }
                    if (char == '#' || char == ';') {
                        break;
                    }
                    if (swticher == false) {
                        key += char;
                        continue;
                    }
                    else {
                        value += char;
                        continue;
                    }
                }
                result.sections.get(currentSectionCounter).keys.add(new Key(key, value.trim()));
            }
        }
        return result;
    };
    /**
     * Convert INI object to string
     *
     * @static
     * @param {INI} ini
     * @returns {string}
     */
    INI.convertToString = function (ini) {
        var result = "";
        for (var i = 0; i < ini.sections.count; i++) {
            var tmpSection = ini.sections.get(i);
            result += "[" + tmpSection.name + "]\n";
            for (var j = 0; j < tmpSection.keys.count; j++) {
                var tmpKey = tmpSection.keys.get(j);
                result += tmpKey.key + " = " + tmpKey.value.toString() + "\n";
            }
        }
        return result;
    };
    /**
     * The section checking regex
     *
     * @private
     * @static
     */
    INI._sectionRegex = /\[(.*)\]/;
    return INI;
}());
exports.INI = INI;
